# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlSignaalkabelAdersEnSectie(KeuzelijstField):
    """Lijst van mogelijke waarden volgens de catalogusposten van het standaardbestek voor de samenstelling van een signalisatiekabel volgens het aantal aders en hun sectie in vierkante millimeter."""
    naam = 'KlSignaalkabelAdersEnSectie'
    label = 'Voedingskabel aders specificaties'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlSignaalkabelAdersEnSectie'
    definition = 'Lijst van mogelijke waarden volgens de catalogusposten van het standaardbestek voor de samenstelling van een signalisatiekabel volgens het aantal aders en hun sectie in vierkante millimeter.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlSignaalkabelAdersEnSectie'
    options = {
        '1.5': KeuzelijstWaarde(invulwaarde='1.5',
                                label='1.5',
                                status='ingebruik',
                                definitie='1.5',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/1.5'),
        '10-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='10-x-1.5-mm2',
                                         label='10 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/10-x-1.5-mm2'),
        '10-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='10-x-2.5-mm2',
                                         label='10 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/10-x-2.5-mm2'),
        '10x1.5': KeuzelijstWaarde(invulwaarde='10x1.5',
                                   label='10x1.5',
                                   status='ingebruik',
                                   definitie='10x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/10x1.5'),
        '10x2x0.2': KeuzelijstWaarde(invulwaarde='10x2x0.2',
                                     label='10x2x0.2',
                                     status='ingebruik',
                                     definitie='10x2x0.2',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/10x2x0.2'),
        '10x2x0.5': KeuzelijstWaarde(invulwaarde='10x2x0.5',
                                     label='10x2x0.5',
                                     status='ingebruik',
                                     definitie='10x2x0.5',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/10x2x0.5'),
        '10x2x0.8': KeuzelijstWaarde(invulwaarde='10x2x0.8',
                                     label='10x2x0.8',
                                     status='ingebruik',
                                     definitie='10x2x0.8',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/10x2x0.8'),
        '12-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='12-x-1.5-mm2',
                                         label='12 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/12-x-1.5-mm2'),
        '12x0.75': KeuzelijstWaarde(invulwaarde='12x0.75',
                                    label='12x0.75',
                                    status='ingebruik',
                                    definitie='12x0.75',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/12x0.75'),
        '12x1.5': KeuzelijstWaarde(invulwaarde='12x1.5',
                                   label='12x1.5',
                                   status='ingebruik',
                                   definitie='12x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/12x1.5'),
        '12x2.5': KeuzelijstWaarde(invulwaarde='12x2.5',
                                   label='12x2.5',
                                   status='ingebruik',
                                   definitie='12x2.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/12x2.5'),
        '12x2x0.8': KeuzelijstWaarde(invulwaarde='12x2x0.8',
                                     label='12x2x0.8',
                                     status='ingebruik',
                                     definitie='12x2x0.8',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/12x2x0.8'),
        '12x3.5': KeuzelijstWaarde(invulwaarde='12x3.5',
                                   label='12x3.5',
                                   status='ingebruik',
                                   definitie='12x3.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/12x3.5'),
        '14-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='14-x-1.5-mm2',
                                         label='14 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/14-x-1.5-mm2'),
        '14-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='14-x-2.5-mm2',
                                         label='14 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/14-x-2.5-mm2'),
        '14x1.5': KeuzelijstWaarde(invulwaarde='14x1.5',
                                   label='14x1.5',
                                   status='ingebruik',
                                   definitie='14x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/14x1.5'),
        '16-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='16-x-1.5-mm2',
                                         label='16 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/16-x-1.5-mm2'),
        '16-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='16-x-2.5-mm2',
                                         label='16 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/16-x-2.5-mm2'),
        '18x1.5': KeuzelijstWaarde(invulwaarde='18x1.5',
                                   label='18x1.5',
                                   status='ingebruik',
                                   definitie='18x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/18x1.5'),
        '19-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='19-x-1.5-mm2',
                                         label='19 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/19-x-1.5-mm2'),
        '19-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='19-x-2.5-mm2',
                                         label='19 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/19-x-2.5-mm2'),
        '19x1.5': KeuzelijstWaarde(invulwaarde='19x1.5',
                                   label='19x1.5',
                                   status='ingebruik',
                                   definitie='19x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/19x1.5'),
        '1x1.5': KeuzelijstWaarde(invulwaarde='1x1.5',
                                  label='1x1.5',
                                  status='ingebruik',
                                  definitie='1x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/1x1.5'),
        '1x2x0.8': KeuzelijstWaarde(invulwaarde='1x2x0.8',
                                    label='1x2x0.8',
                                    status='ingebruik',
                                    definitie='1x2x0.8',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/1x2x0.8'),
        '20x1.5': KeuzelijstWaarde(invulwaarde='20x1.5',
                                   label='20x1.5',
                                   status='ingebruik',
                                   definitie='20x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/20x1.5'),
        '21-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='21-x-1.5-mm2',
                                         label='21 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/21-x-1.5-mm2'),
        '21-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='21-x-2.5-mm2',
                                         label='21 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/21-x-2.5-mm2'),
        '21x2x0.8': KeuzelijstWaarde(invulwaarde='21x2x0.8',
                                     label='21x2x0.8',
                                     status='ingebruik',
                                     definitie='21x2x0.8',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/21x2x0.8'),
        '24-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='24-x-1.5-mm2',
                                         label='24 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/24-x-1.5-mm2'),
        '24-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='24-x-2.5-mm2',
                                         label='24 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/24-x-2.5-mm2'),
        '25x0.75': KeuzelijstWaarde(invulwaarde='25x0.75',
                                    label='25x0.75',
                                    status='ingebruik',
                                    definitie='25x0.75',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/25x0.75'),
        '25x1.5': KeuzelijstWaarde(invulwaarde='25x1.5',
                                   label='25x1.5',
                                   status='ingebruik',
                                   definitie='25x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/25x1.5'),
        '27-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='27-x-1.5-mm2',
                                         label='27 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/27-x-1.5-mm2'),
        '27-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='27-x-2.5-mm2',
                                         label='27 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/27-x-2.5-mm2'),
        '27x1.5': KeuzelijstWaarde(invulwaarde='27x1.5',
                                   label='27x1.5',
                                   status='ingebruik',
                                   definitie='27x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/27x1.5'),
        '2x0.75': KeuzelijstWaarde(invulwaarde='2x0.75',
                                   label='2x0.75',
                                   status='ingebruik',
                                   definitie='2x0.75',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/2x0.75'),
        '2x1.5': KeuzelijstWaarde(invulwaarde='2x1.5',
                                  label='2x1.5',
                                  status='ingebruik',
                                  definitie='2x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/2x1.5'),
        '2x2.5': KeuzelijstWaarde(invulwaarde='2x2.5',
                                  label='2x2.5',
                                  status='ingebruik',
                                  definitie='2x2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/2x2.5'),
        '2x2x0.5': KeuzelijstWaarde(invulwaarde='2x2x0.5',
                                    label='2x2x0.5',
                                    status='ingebruik',
                                    definitie='2x2x0.5',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/2x2x0.5'),
        '2x2x0.75': KeuzelijstWaarde(invulwaarde='2x2x0.75',
                                     label='2x2x0.75',
                                     status='ingebruik',
                                     definitie='2x2x0.75',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/2x2x0.75'),
        '2x2x0.8': KeuzelijstWaarde(invulwaarde='2x2x0.8',
                                    label='2x2x0.8',
                                    status='ingebruik',
                                    definitie='2x2x0.8',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/2x2x0.8'),
        '2x2x2.5': KeuzelijstWaarde(invulwaarde='2x2x2.5',
                                    label='2x2x2.5',
                                    status='ingebruik',
                                    definitie='2x2x2.5',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/2x2x2.5'),
        '2x4': KeuzelijstWaarde(invulwaarde='2x4',
                                label='2x4',
                                status='ingebruik',
                                definitie='2x4',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/2x4'),
        '30-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='30-x-1.5-mm2',
                                         label='30 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/30-x-1.5-mm2'),
        '30-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='30-x-2.5-mm2',
                                         label='30 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/30-x-2.5-mm2'),
        '30x1.5': KeuzelijstWaarde(invulwaarde='30x1.5',
                                   label='30x1.5',
                                   status='ingebruik',
                                   definitie='30x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/30x1.5'),
        '30x2.5': KeuzelijstWaarde(invulwaarde='30x2.5',
                                   label='30x2.5',
                                   status='ingebruik',
                                   definitie='30x2.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/30x2.5'),
        '33-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='33-x-1.5-mm2',
                                         label='33 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/33-x-1.5-mm2'),
        '33-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='33-x-2.5-mm2',
                                         label='33 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/33-x-2.5-mm2'),
        '37-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='37-x-1.5-mm2',
                                         label='37 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/37-x-1.5-mm2'),
        '37-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='37-x-2.5-mm2',
                                         label='37 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/37-x-2.5-mm2'),
        '37x1.5': KeuzelijstWaarde(invulwaarde='37x1.5',
                                   label='37x1.5',
                                   status='ingebruik',
                                   definitie='37x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/37x1.5'),
        '3x0.75': KeuzelijstWaarde(invulwaarde='3x0.75',
                                   label='3x0.75',
                                   status='ingebruik',
                                   definitie='3x0.75',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/3x0.75'),
        '3x1.5': KeuzelijstWaarde(invulwaarde='3x1.5',
                                  label='3x1.5',
                                  status='ingebruik',
                                  definitie='3x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/3x1.5'),
        '40-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='40-x-1.5-mm2',
                                         label='40 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/40-x-1.5-mm2'),
        '40-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='40-x-2.5-mm2',
                                         label='40 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/40-x-2.5-mm2'),
        '44-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='44-x-1.5-mm2',
                                         label='44 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/44-x-1.5-mm2'),
        '44-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='44-x-2.5-mm2',
                                         label='44 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/44-x-2.5-mm2'),
        '48-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='48-x-1.5-mm2',
                                         label='48 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/48-x-1.5-mm2'),
        '48-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='48-x-2.5-mm2',
                                         label='48 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/48-x-2.5-mm2'),
        '48x0.8': KeuzelijstWaarde(invulwaarde='48x0.8',
                                   label='48x0.8',
                                   status='ingebruik',
                                   definitie='48x0.8',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/48x0.8'),
        '48x1.5': KeuzelijstWaarde(invulwaarde='48x1.5',
                                   label='48x1.5',
                                   status='ingebruik',
                                   definitie='48x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/48x1.5'),
        '4x0.8': KeuzelijstWaarde(invulwaarde='4x0.8',
                                  label='4x0.8',
                                  status='ingebruik',
                                  definitie='4x0.8',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/4x0.8'),
        '4x1.5': KeuzelijstWaarde(invulwaarde='4x1.5',
                                  label='4x1.5',
                                  status='ingebruik',
                                  definitie='4x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/4x1.5'),
        '4x2.5': KeuzelijstWaarde(invulwaarde='4x2.5',
                                  label='4x2.5',
                                  status='ingebruik',
                                  definitie='4x2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/4x2.5'),
        '4x25': KeuzelijstWaarde(invulwaarde='4x25',
                                 label='4x25',
                                 status='ingebruik',
                                 definitie='4x25',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/4x25'),
        '4x25-16': KeuzelijstWaarde(invulwaarde='4x25-16',
                                    label='4x25+16',
                                    status='ingebruik',
                                    definitie='4x25+16',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/4x25-16'),
        '4x2x0.5': KeuzelijstWaarde(invulwaarde='4x2x0.5',
                                    label='4x2x0.5',
                                    status='ingebruik',
                                    definitie='4x2x0.5',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/4x2x0.5'),
        '4x2x0.8': KeuzelijstWaarde(invulwaarde='4x2x0.8',
                                    label='4x2x0.8',
                                    status='ingebruik',
                                    definitie='4x2x0.8',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/4x2x0.8'),
        '5-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='5-x-1.5-mm2',
                                        label='5 x 1.5 mm²',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/5-x-1.5-mm2'),
        '5-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='5-x-2.5-mm2',
                                        label='5 x 2.5 mm²',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/5-x-2.5-mm2'),
        '5x0.75': KeuzelijstWaarde(invulwaarde='5x0.75',
                                   label='5x0.75',
                                   status='ingebruik',
                                   definitie='5x0.75',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/5x0.75'),
        '5x2x0.8': KeuzelijstWaarde(invulwaarde='5x2x0.8',
                                    label='5x2x0.8',
                                    status='ingebruik',
                                    definitie='5x2x0.8',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/5x2x0.8'),
        '60x1.5': KeuzelijstWaarde(invulwaarde='60x1.5',
                                   label='60x1.5',
                                   status='ingebruik',
                                   definitie='60x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/60x1.5'),
        '61-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='61-x-1.5-mm2',
                                         label='61 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/61-x-1.5-mm2'),
        '61-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='61-x-2.5-mm2',
                                         label='61 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/61-x-2.5-mm2'),
        '61x1.5': KeuzelijstWaarde(invulwaarde='61x1.5',
                                   label='61x1.5',
                                   status='ingebruik',
                                   definitie='61x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/61x1.5'),
        '7-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='7-x-1.5-mm2',
                                        label='7 x 1.5 mm²',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/7-x-1.5-mm2'),
        '7-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='7-x-2.5-mm2',
                                        label='7 x 2.5 mm²',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/7-x-2.5-mm2'),
        '7x0.75': KeuzelijstWaarde(invulwaarde='7x0.75',
                                   label='7x0.75',
                                   status='ingebruik',
                                   definitie='7x0.75',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/7x0.75'),
        '7x1.5': KeuzelijstWaarde(invulwaarde='7x1.5',
                                  label='7x1.5',
                                  status='ingebruik',
                                  definitie='7x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/7x1.5'),
        '7x2x0.8': KeuzelijstWaarde(invulwaarde='7x2x0.8',
                                    label='7x2x0.8',
                                    status='ingebruik',
                                    definitie='7x2x0.8',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/7x2x0.8'),
        '8-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='8-x-1.5-mm2',
                                        label='8 x 1.5 mm²',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/8-x-1.5-mm2'),
        '8-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='8-x-2.5-mm2',
                                        label='8 x 2.5 mm²',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/8-x-2.5-mm2'),
        '8x1.5': KeuzelijstWaarde(invulwaarde='8x1.5',
                                  label='8x1.5',
                                  status='ingebruik',
                                  definitie='8x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/8x1.5'),
        '8x2x0.5': KeuzelijstWaarde(invulwaarde='8x2x0.5',
                                    label='8x2x0.5',
                                    status='ingebruik',
                                    definitie='8x2x0.5',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/8x2x0.5'),
        '8x2x0.8': KeuzelijstWaarde(invulwaarde='8x2x0.8',
                                    label='8x2x0.8',
                                    status='ingebruik',
                                    definitie='8x2x0.8',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/8x2x0.8'),
        'zonder-bijkomende-specificatie': KeuzelijstWaarde(invulwaarde='zonder-bijkomende-specificatie',
                                                           label='zonder bijkomende specificatie',
                                                           status='ingebruik',
                                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/zonder-bijkomende-specificatie')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.ConstructiefObject import ConstructiefObject
from otlmow_model.Datatypes.KlTypeVakwerkElement import KlTypeVakwerkElement
from otlmow_model.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class VakwerkElement(ConstructiefObject, VlakGeometrie):
    """Element dat deel uitmaakt van een constructie waarbij balken en staven, volgens een stelsel van rechthoeken en/of driehoeken, aan de uiteinden en/of kruiselings verbonden worden tot een onwrikbaar geheel."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VakwerkElement'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        ConstructiefObject.__init__(self)
        VlakGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Balk')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugligger')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kolom')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Windverband')

        self._typeVakwerkElement = OTLAttribuut(field=KlTypeVakwerkElement,
                                                naam='typeVakwerkElement',
                                                label='type vakwerk-element',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VakwerkElement.typeVakwerkElement',
                                                definition='Het type van vakwerk-element.',
                                                owner=self)

    @property
    def typeVakwerkElement(self) -> str:
        """Het type van vakwerk-element."""
        return self._typeVakwerkElement.get_waarde()

    @typeVakwerkElement.setter
    def typeVakwerkElement(self, value):
        self._typeVakwerkElement.set_waarde(value, owner=self)



# coding=utf-8
from datetime import date
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.BaseClasses.DateField import DateField
from otlmow_model.Datatypes.KwantWrdInkWh import KwantWrdInkWh, KwantWrdInkWhWaarden
from otlmow_model.GeometrieTypes.GeenGeometrie import GeenGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class MeteropnameEnergiemeter(AIMNaamObject, GeenGeometrie):
    """Resultaten van een meteropname van een energiemeter."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#MeteropnameEnergiemeter'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMNaamObject.__init__(self)
        GeenGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#DNBMeter')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Energiemeter')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#EnergiemeterAWV')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#EnergiemeterDNB')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#EnergiemeterDNBPiek')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#EnergiemeterDNBReactief')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#EnergiemeterDerden')

        self._datumMeterstand = OTLAttribuut(field=DateField,
                                             naam='datumMeterstand',
                                             label='datum meterstand dag',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#MeteropnameEnergiemeter.datumMeterstand',
                                             definition='De datum van de laatste meteropname van de energiemeter.',
                                             owner=self)

        self._meterstandDag = OTLAttribuut(field=KwantWrdInkWh,
                                           naam='meterstandDag',
                                           label='meterstand dag',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#MeteropnameEnergiemeter.meterstandDag',
                                           definition='De meterstand bij de laatste meteropname van de dag-energiemeter.',
                                           owner=self)

        self._meterstandNacht = OTLAttribuut(field=KwantWrdInkWh,
                                             naam='meterstandNacht',
                                             label='meterstand nacht',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#MeteropnameEnergiemeter.meterstandNacht',
                                             definition='De meterstand bij de laatste meteropname van de nacht-energiemeter.',
                                             owner=self)

    @property
    def datumMeterstand(self) -> date:
        """De datum van de laatste meteropname van de energiemeter."""
        return self._datumMeterstand.get_waarde()

    @datumMeterstand.setter
    def datumMeterstand(self, value):
        self._datumMeterstand.set_waarde(value, owner=self)

    @property
    def meterstandDag(self) -> KwantWrdInkWhWaarden:
        """De meterstand bij de laatste meteropname van de dag-energiemeter."""
        return self._meterstandDag.get_waarde()

    @meterstandDag.setter
    def meterstandDag(self, value):
        self._meterstandDag.set_waarde(value, owner=self)

    @property
    def meterstandNacht(self) -> KwantWrdInkWhWaarden:
        """De meterstand bij de laatste meteropname van de nacht-energiemeter."""
        return self._meterstandNacht.get_waarde()

    @meterstandNacht.setter
    def meterstandNacht(self, value):
        self._meterstandNacht.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.Controller import Controller
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.Datatypes.KlPLCMerk import KlPLCMerk
from otlmow_model.Datatypes.KlPLCModelnaam import KlPLCModelnaam


# Generated with OTLClassCreator. To modify: extend, do not edit
class PLC(Controller):
    """Een verwerkingseenheid die volgens een vaste cyclus op basis van informatie van zijn ingangen, zijn uitgangen aanstuurt op basis van zijn programma. Omwille van zijn vormfactor kan de eenheid gebruikt worden in een vijandige omgeving."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PLC'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IOKaart')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Rack')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Meetstation')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Niveaumeting')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Display')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Elektromotor')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IOKaart')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Omvormer')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Software')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stroomkring')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stuurklep')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Veiligheidsrelais')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Sensor')

        self._merk = OTLAttribuut(field=KlPLCMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PLC.merk',
                                  definition='Het merk van de PLC.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlPLCModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PLC.modelnaam',
                                       definition='De modelnaam van de PLC.',
                                       owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technischeFiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PLC.technischeFiche',
                                             definition='De technische fiche van de PLC.',
                                             owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de PLC."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van de PLC."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van de PLC."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.Kabel import Kabel
from otlmow_model.Datatypes.KlVoedingskabelAdersEnSectie import KlVoedingskabelAdersEnSectie
from otlmow_model.Datatypes.KlVoedingskabelType import KlVoedingskabelType
from otlmow_model.Datatypes.KlVoedingskabelTypeSpecificatie import KlVoedingskabelTypeSpecificatie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Voedingskabel(Kabel):
    """Zorgt voor het overbrengen van een elektrisch vermogen van de ene locatie naar de andere binnen een privaat netwerk. Onder dit type vallen ook installatiedraden die beschouwd worden als kabels met slechts één ader."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedingskabel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self._aantalAdersEnSectie = OTLAttribuut(field=KlVoedingskabelAdersEnSectie,
                                                 naam='aantalAdersEnSectie',
                                                 label='aantal aders en sectie',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedingskabel.aantalAdersEnSectie',
                                                 definition='Aantal en sectie van de ader(s) van de kabel volgens een lijst van voorkomende types.',
                                                 owner=self)

        self._type = OTLAttribuut(field=KlVoedingskabelType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedingskabel.type',
                                  definition='Indeling van een energie- of installatiekabel of -draad op basis van de gebruikte materialen en volgens een vaste typering.',
                                  owner=self)

        self._typeSpecificatie = OTLAttribuut(field=KlVoedingskabelTypeSpecificatie,
                                              naam='typeSpecificatie',
                                              label='type specificatie',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedingskabel.typeSpecificatie',
                                              definition='Een verdere specificatie van het type van de voedingskabel volgens een vaste lijst om bv. de brandklasse mee te geven.',
                                              owner=self)

    @property
    def aantalAdersEnSectie(self) -> str:
        """Aantal en sectie van de ader(s) van de kabel volgens een lijst van voorkomende types."""
        return self._aantalAdersEnSectie.get_waarde()

    @aantalAdersEnSectie.setter
    def aantalAdersEnSectie(self, value):
        self._aantalAdersEnSectie.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Indeling van een energie- of installatiekabel of -draad op basis van de gebruikte materialen en volgens een vaste typering."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)

    @property
    def typeSpecificatie(self) -> str:
        """Een verdere specificatie van het type van de voedingskabel volgens een vaste lijst om bv. de brandklasse mee te geven."""
        return self._typeSpecificatie.get_waarde()

    @typeSpecificatie.setter
    def typeSpecificatie(self, value):
        self._typeSpecificatie.set_waarde(value, owner=self)



# coding=utf-8
from typing import List
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.BaseClasses.BooleanField import BooleanField
from otlmow_model.Datatypes.DtcCameraBeeldverwerking import DtcCameraBeeldverwerking, DtcCameraBeeldverwerkingWaarden
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.Datatypes.DteIPv4Adres import DteIPv4Adres, DteIPv4AdresWaarden
from otlmow_model.Datatypes.KlCameraMerk import KlCameraMerk
from otlmow_model.Datatypes.KlCameraModelnaam import KlCameraModelnaam
from otlmow_model.Datatypes.KlServicePrioriteit import KlServicePrioriteit
from otlmow_model.Datatypes.KlSpectrum import KlSpectrum
from otlmow_model.Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.BaseClasses.StringField import StringField
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Camera(AIMNaamObject, PuntGeometrie):
    """Een CCTV-camera, closed-circuit television camera, kortweg camera, produceert beelden of opnames voor bewaking van een regio vanop afstand. Het is een element dat beelden neemt van een locatie en deze doorgeeft naar verschillende partijen om zo de werkelijke situatie te kunnen inschatten vanop afstand. Deze camera kan van het analoge type zijn of digitaal."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Camera'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMNaamObject.__init__(self)
        PuntGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Draagconstructie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestigingsbeugel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#FieldOfView', deprecated='2.4.0')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Meetstation')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Zoutbijlaadplaats')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SoftwareToegang')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#AIDModule')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkpoort')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Omvormer')

        self._beeldverwerkingsinstelling = OTLAttribuut(field=DtcCameraBeeldverwerking,
                                                        naam='beeldverwerkingsinstelling',
                                                        label='beeldverwerkingsinstelling',
                                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Camera.beeldverwerkingsinstelling',
                                                        usagenote='Wanneer de camera de beeldverwerking niet zelf doet maar enkel beelden  verstuurt voor verwerking in een externe eenheid, moet die externe eenheid als aparte asset aangemaakt worden indien het specifieke type bestaat in de OTL of moet een instantie van Software gebruikt worden wanneer geen specifieke externe verwerkingseenheid voorzien is. Dit attribuut kan dus enkel gebruikt worden indien de camera of een verwerkingseenheid van de camera zelf de analyse doet en die analyse doorstuurt naar een asset die met de analyse werkt en niet met de beelden.',
                                                        kardinaliteit_max='*',
                                                        definition='Geeft aan welke types beeldverwerking die camera zelf uitvoert dus zonder gebruik te maken van een externe verwerkingseenheid.',
                                                        owner=self)

        self._configBestandAid = OTLAttribuut(field=DtcDocument,
                                              naam='configBestandAid',
                                              label='configuratie bestand AID',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Camera.configBestandAid',
                                              usagenote='Attribuut uit gebruik sinds versie 2.3.0 ',
                                              deprecated_version='2.3.0',
                                              definition='Het bestand met de configuratie van de AID component die deel is van de camera.',
                                              owner=self)

        self._dnsNaam = OTLAttribuut(field=StringField,
                                     naam='dnsNaam',
                                     label='DNS naam',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Camera.dnsNaam',
                                     definition='De DNSNaam (ook "volledige domein naam" genoemd ) is een unieke naam binnen het Domain Name System (DNS), het naamgevingssysteem waarmee computers, webservers, diensten en toepassing op een unieke manier kunnen worden geïdentificeerd. Deze bevat zowel de hostname en de top level domein naam bv. 120c8-ar1.belfa.be.',
                                     owner=self)

        self._heeftAid = OTLAttribuut(field=BooleanField,
                                      naam='heeftAid',
                                      label='heeft AID',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Camera.heeftAid',
                                      usagenote='Attribuut uit gebruik sinds versie 2.3.0 ',
                                      deprecated_version='2.3.0',
                                      definition='Een AID-camera is een CCTV-camera met geintegreerde AID-module. Deze camera genereert naast een camerabeeld ook metadata ivm wat zich afspeelt op het beeld. Een voorbeeld hiervan is gestopte voertuigen.',
                                      owner=self)

        self._heeftSpitsstrook = OTLAttribuut(field=BooleanField,
                                              naam='heeftSpitsstrook',
                                              label='heeft spitsstrook',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Camera.heeftSpitsstrook',
                                              usagenote='Attribuut uit gebruik sinds versie 2.3.0 ',
                                              deprecated_version='2.3.0',
                                              definition='Locatie-eigenschap van een camera. Dit attribuut geeft aan of de camera ingezet wordt om een spitsstrook te schouwen.',
                                              owner=self)

        self._ipAdres = OTLAttribuut(field=DteIPv4Adres,
                                     naam='ipAdres',
                                     label='ip adres',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Camera.ipAdres',
                                     definition='Het IP-adres van de camera.',
                                     owner=self)

        self._isPtz = OTLAttribuut(field=BooleanField,
                                   naam='isPtz',
                                   label='is PTZ',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Camera.isPtz',
                                   definition='Een PTZ-camera is een CCTV-camera met bijhorend de mogelijkheid om te pannen, tilten en zoomen. Dit vanop afstand met behulp van een verstelbare lens en een motor die in twee assen draaibeweging toelaat.',
                                   owner=self)

        self._merk = OTLAttribuut(field=KlCameraMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Camera.merk',
                                  definition='Het merk van de camera.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlCameraModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Camera.modelnaam',
                                       definition='De modelnaam van de camera.',
                                       owner=self)

        self._opstelhoogte = OTLAttribuut(field=KwantWrdInMeter,
                                          naam='opstelhoogte',
                                          label='opstelhoogte',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Camera.opstelhoogte',
                                          usagenote='De plaats waar de draagconstructie in de grond bevestigd is, bepaalt van waar gemeten wordt voor het bepalen van de opstelhoogte. Wanneer een camera die een brugdek overziet, bevestigd is aan een paal die naast de brug staat, wordt de hoogte gemeten vanaf de basis van de paal en niet vanaf het brugdek. ',
                                          definition='De hoogte waarop de camera bevestigd is, gemeten ten opzichte van het maaiveld waarin de draagconstructie voor de camera verankerd is.',
                                          owner=self)

        self._servicePrioriteit = OTLAttribuut(field=KlServicePrioriteit,
                                               naam='servicePrioriteit',
                                               label='service prioriteit',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Camera.servicePrioriteit',
                                               definition='Het prioriteitsniveau dat aangeeft hoe dringend iets moet onderhouden/gerepareerd worden.',
                                               owner=self)

        self._spectrum = OTLAttribuut(field=KlSpectrum,
                                      naam='spectrum',
                                      label='spectrum',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Camera.spectrum',
                                      definition='De golflengte van de invallende straling.',
                                      owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Camera.technischeFiche',
                                             usagenote='Bestanden van het type pdf.',
                                             definition="Technische fiche van dit element met opsplitsing tussen CCTV, AID en PTZ-camera's.",
                                             owner=self)

    @property
    def beeldverwerkingsinstelling(self) -> List[DtcCameraBeeldverwerkingWaarden]:
        """Geeft aan welke types beeldverwerking die camera zelf uitvoert dus zonder gebruik te maken van een externe verwerkingseenheid."""
        return self._beeldverwerkingsinstelling.get_waarde()

    @beeldverwerkingsinstelling.setter
    def beeldverwerkingsinstelling(self, value):
        self._beeldverwerkingsinstelling.set_waarde(value, owner=self)

    @property
    def configBestandAid(self) -> DtcDocumentWaarden:
        """Het bestand met de configuratie van de AID component die deel is van de camera."""
        return self._configBestandAid.get_waarde()

    @configBestandAid.setter
    def configBestandAid(self, value):
        self._configBestandAid.set_waarde(value, owner=self)

    @property
    def dnsNaam(self) -> str:
        """De DNSNaam (ook "volledige domein naam" genoemd ) is een unieke naam binnen het Domain Name System (DNS), het naamgevingssysteem waarmee computers, webservers, diensten en toepassing op een unieke manier kunnen worden geïdentificeerd. Deze bevat zowel de hostname en de top level domein naam bv. 120c8-ar1.belfa.be."""
        return self._dnsNaam.get_waarde()

    @dnsNaam.setter
    def dnsNaam(self, value):
        self._dnsNaam.set_waarde(value, owner=self)

    @property
    def heeftAid(self) -> bool:
        """Een AID-camera is een CCTV-camera met geintegreerde AID-module. Deze camera genereert naast een camerabeeld ook metadata ivm wat zich afspeelt op het beeld. Een voorbeeld hiervan is gestopte voertuigen."""
        return self._heeftAid.get_waarde()

    @heeftAid.setter
    def heeftAid(self, value):
        self._heeftAid.set_waarde(value, owner=self)

    @property
    def heeftSpitsstrook(self) -> bool:
        """Locatie-eigenschap van een camera. Dit attribuut geeft aan of de camera ingezet wordt om een spitsstrook te schouwen."""
        return self._heeftSpitsstrook.get_waarde()

    @heeftSpitsstrook.setter
    def heeftSpitsstrook(self, value):
        self._heeftSpitsstrook.set_waarde(value, owner=self)

    @property
    def ipAdres(self) -> DteIPv4AdresWaarden:
        """Het IP-adres van de camera."""
        return self._ipAdres.get_waarde()

    @ipAdres.setter
    def ipAdres(self, value):
        self._ipAdres.set_waarde(value, owner=self)

    @property
    def isPtz(self) -> bool:
        """Een PTZ-camera is een CCTV-camera met bijhorend de mogelijkheid om te pannen, tilten en zoomen. Dit vanop afstand met behulp van een verstelbare lens en een motor die in twee assen draaibeweging toelaat."""
        return self._isPtz.get_waarde()

    @isPtz.setter
    def isPtz(self, value):
        self._isPtz.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de camera."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van de camera."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def opstelhoogte(self) -> KwantWrdInMeterWaarden:
        """De hoogte waarop de camera bevestigd is, gemeten ten opzichte van het maaiveld waarin de draagconstructie voor de camera verankerd is."""
        return self._opstelhoogte.get_waarde()

    @opstelhoogte.setter
    def opstelhoogte(self, value):
        self._opstelhoogte.set_waarde(value, owner=self)

    @property
    def servicePrioriteit(self) -> str:
        """Het prioriteitsniveau dat aangeeft hoe dringend iets moet onderhouden/gerepareerd worden."""
        return self._servicePrioriteit.get_waarde()

    @servicePrioriteit.setter
    def servicePrioriteit(self, value):
        self._servicePrioriteit.set_waarde(value, owner=self)

    @property
    def spectrum(self) -> str:
        """De golflengte van de invallende straling."""
        return self._spectrum.get_waarde()

    @spectrum.setter
    def spectrum(self, value):
        self._spectrum.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """Technische fiche van dit element met opsplitsing tussen CCTV, AID en PTZ-camera's."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLEGCMateriaal(KeuzelijstField):
    """Materialen van de geluidswerende constructie."""
    naam = 'KlLEGCMateriaal'
    label = 'Materiaal geluidswerende constructie'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlLEGCMateriaal'
    definition = 'Materialen van de geluidswerende constructie.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLEGCMateriaal'
    options = {
        'bakstenen': KeuzelijstWaarde(invulwaarde='bakstenen',
                                      label='bakstenen',
                                      status='ingebruik',
                                      definitie='bakstenen',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCMateriaal/bakstenen'),
        'beton': KeuzelijstWaarde(invulwaarde='beton',
                                  label='beton',
                                  status='ingebruik',
                                  definitie='beton',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCMateriaal/beton'),
        'beton---houtvezelbeton': KeuzelijstWaarde(invulwaarde='beton---houtvezelbeton',
                                                   label='beton - houtvezelbeton',
                                                   status='ingebruik',
                                                   definitie='beton - houtvezelbeton',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCMateriaal/beton---houtvezelbeton'),
        'beton---lichtgewichtbeton': KeuzelijstWaarde(invulwaarde='beton---lichtgewichtbeton',
                                                      label='beton - lichtgewichtbeton',
                                                      status='ingebruik',
                                                      definitie='beton - lichtgewichtbeton',
                                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCMateriaal/beton---lichtgewichtbeton'),
        'beton---steenparament': KeuzelijstWaarde(invulwaarde='beton---steenparament',
                                                  label='beton - steenparament',
                                                  status='ingebruik',
                                                  definitie='Beton - steenparament',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCMateriaal/beton---steenparament'),
        'glas': KeuzelijstWaarde(invulwaarde='glas',
                                 label='glas',
                                 status='ingebruik',
                                 definitie='glas',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCMateriaal/glas'),
        'groenscherm': KeuzelijstWaarde(invulwaarde='groenscherm',
                                        label='groenscherm',
                                        status='ingebruik',
                                        definitie='groenscherm',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCMateriaal/groenscherm'),
        'hout': KeuzelijstWaarde(invulwaarde='hout',
                                 label='hout',
                                 status='ingebruik',
                                 definitie='hout',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCMateriaal/hout'),
        'kokospanelen': KeuzelijstWaarde(invulwaarde='kokospanelen',
                                         label='kokospanelen',
                                         status='ingebruik',
                                         definitie='kokospanelen',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCMateriaal/kokospanelen'),
        'kunststof---PMMA': KeuzelijstWaarde(invulwaarde='kunststof---PMMA',
                                             label='kunststof - PMMA',
                                             status='ingebruik',
                                             definitie='Kunststof - PMMA',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCMateriaal/kunststof---PMMA'),
        'kunststof---PVC': KeuzelijstWaarde(invulwaarde='kunststof---PVC',
                                            label='kunststof - PVC',
                                            status='ingebruik',
                                            definitie='kunststof - PVC',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCMateriaal/kunststof---PVC'),
        'metaal---aluminium': KeuzelijstWaarde(invulwaarde='metaal---aluminium',
                                               label='metaal - aluminium',
                                               status='ingebruik',
                                               definitie='Metaal - aluminium',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCMateriaal/metaal---aluminium'),
        'metaal---aluminium-en-staal': KeuzelijstWaarde(invulwaarde='metaal---aluminium-en-staal',
                                                        label='metaal - aluminium en staal',
                                                        status='ingebruik',
                                                        definitie='Metaal - aluminium en staal',
                                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCMateriaal/metaal---aluminium-en-staal'),
        'metaal---staal': KeuzelijstWaarde(invulwaarde='metaal---staal',
                                           label='metaal - staal',
                                           status='ingebruik',
                                           definitie='metaal - staal',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCMateriaal/metaal---staal'),
        'stalen-raster-met-beschermnet-in-kunststof': KeuzelijstWaarde(invulwaarde='stalen-raster-met-beschermnet-in-kunststof',
                                                                       label='stalen raster met beschermnet in kunststof',
                                                                       status='ingebruik',
                                                                       definitie='stalen raster met beschermnet in kunststof',
                                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCMateriaal/stalen-raster-met-beschermnet-in-kunststof'),
        'tunnelplaat': KeuzelijstWaarde(invulwaarde='tunnelplaat',
                                        label='tunnelplaat',
                                        status='ingebruik',
                                        definitie='tunnelplaat',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCMateriaal/tunnelplaat')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.ElektrischComponentennummerObject import ElektrischComponentennummerObject
from otlmow_model.Classes.Abstracten.SerienummerObject import SerienummerObject
from otlmow_model.Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.BaseClasses.BooleanField import BooleanField
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.BaseClasses.FloatOrDecimalField import FloatOrDecimalField
from otlmow_model.Datatypes.KlElektromotorBeschermingsgraad import KlElektromotorBeschermingsgraad
from otlmow_model.Datatypes.KlElektromotorBouwvorm import KlElektromotorBouwvorm
from otlmow_model.Datatypes.KlElektromotorMerk import KlElektromotorMerk
from otlmow_model.Datatypes.KlElektromotorModelnaam import KlElektromotorModelnaam
from otlmow_model.Datatypes.KlElektromotorRol import KlElektromotorRol
from otlmow_model.Datatypes.KlNominaleSpanning import KlNominaleSpanning
from otlmow_model.Datatypes.KwantWrdInAmpere import KwantWrdInAmpere, KwantWrdInAmpereWaarden
from otlmow_model.Datatypes.KwantWrdInKiloWatt import KwantWrdInKiloWatt, KwantWrdInKiloWattWaarden
from otlmow_model.Datatypes.KwantWrdInMillimeter import KwantWrdInMillimeter, KwantWrdInMillimeterWaarden
from otlmow_model.Datatypes.KwantWrdInRPM import KwantWrdInRPM, KwantWrdInRPMWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class Elektromotor(AIMNaamObject, ElektrischComponentennummerObject, SerienummerObject):
    """Een machine die elektrische energie omzet in mechanische energie."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Elektromotor'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMNaamObject.__init__(self)
        ElektrischComponentennummerObject.__init__(self)
        SerienummerObject.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Silo')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PLC')

        self._arbeidsfactor = OTLAttribuut(field=FloatOrDecimalField,
                                           naam='arbeidsfactor',
                                           label='arbeidsfactor',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Elektromotor.arbeidsfactor',
                                           definition='De arbeidsfactor of cosinus phi is de verhouding van het effectief elektrisch vermogen en het schijnbaar vermogen. Om het elektrisch net minimaal te belasten moet deze waarde zo dicht mogelijk bij 1 liggen.',
                                           owner=self)

        self._asdiameter = OTLAttribuut(field=KwantWrdInMillimeter,
                                        naam='asdiameter',
                                        label='asdiameter',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Elektromotor.asdiameter',
                                        definition='De diameter van de uitgaande as van de elektromotor.',
                                        owner=self)

        self._ashoogte = OTLAttribuut(field=KwantWrdInMillimeter,
                                      naam='ashoogte',
                                      label='ashoogte',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Elektromotor.ashoogte',
                                      definition='De afstand tussen het rustvlak van de voeten van de elektromotor en het midden van de uitgaande as.',
                                      owner=self)

        self._beschermingsgraad = OTLAttribuut(field=KlElektromotorBeschermingsgraad,
                                               naam='beschermingsgraad',
                                               label='beschermingsgraad',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Elektromotor.beschermingsgraad',
                                               definition='De beschermingsgraad geeft aan in welke mate elektrische apparatuur tegen indringing van vreemde objecten en water bestand is. Dit gebeurt met de code IP, gevolgd door twee cijfers.',
                                               owner=self)

        self._bouwvorm = OTLAttribuut(field=KlElektromotorBouwvorm,
                                      naam='bouwvorm',
                                      label='bouwvorm',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Elektromotor.bouwvorm',
                                      definition='De bouwvorm, uitgedrukt als een IM-code, zegt iets over de wijze waarop de elektromotor gemonteerd is.',
                                      owner=self)

        self._gebruik = OTLAttribuut(field=KlElektromotorRol,
                                     naam='gebruik',
                                     label='gebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Elektromotor.gebruik',
                                     definition='Geeft aan hoe de elektromotor gebruikt wordt in het systeem waar hij deel van uitmaakt.',
                                     owner=self)

        self._heeftGeforceerdeKoeling = OTLAttribuut(field=BooleanField,
                                                     naam='heeftGeforceerdeKoeling',
                                                     label='heeft geforceerde koeling',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Elektromotor.heeftGeforceerdeKoeling',
                                                     definition='Geeft aan of de elektromotor voorzien is van geforceerde koeling.',
                                                     owner=self)

        self._merk = OTLAttribuut(field=KlElektromotorMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Elektromotor.merk',
                                  definition='Het merk van de elektromotor.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlElektromotorModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Elektromotor.modelnaam',
                                       definition='De modelnaam volgens de fabrikant van de elektromotor.',
                                       owner=self)

        self._nominaalToerental = OTLAttribuut(field=KwantWrdInRPM,
                                               naam='nominaalToerental',
                                               label='nominaal toerental',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Elektromotor.nominaalToerental',
                                               definition='Het nominale toerental van de elektromotor.',
                                               owner=self)

        self._nominaalVermogen = OTLAttribuut(field=KwantWrdInKiloWatt,
                                              naam='nominaalVermogen',
                                              label='nominaal vermogen',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Elektromotor.nominaalVermogen',
                                              definition='Het nominale vermogen van de elektromotor.',
                                              owner=self)

        self._nominaleSpanning = OTLAttribuut(field=KlNominaleSpanning,
                                              naam='nominaleSpanning',
                                              label='nominale spanning',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Elektromotor.nominaleSpanning',
                                              definition='De nominale spanning van de elektromotor.',
                                              owner=self)

        self._nominaleStroom = OTLAttribuut(field=KwantWrdInAmpere,
                                            naam='nominaleStroom',
                                            label='nominale stroom',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Elektromotor.nominaleStroom',
                                            definition='De nominale stroom van de elektromotor.',
                                            owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Elektromotor.technischeFiche',
                                             definition='De technische fiche van een elektromotor.',
                                             owner=self)

    @property
    def arbeidsfactor(self) -> float:
        """De arbeidsfactor of cosinus phi is de verhouding van het effectief elektrisch vermogen en het schijnbaar vermogen. Om het elektrisch net minimaal te belasten moet deze waarde zo dicht mogelijk bij 1 liggen."""
        return self._arbeidsfactor.get_waarde()

    @arbeidsfactor.setter
    def arbeidsfactor(self, value):
        self._arbeidsfactor.set_waarde(value, owner=self)

    @property
    def asdiameter(self) -> KwantWrdInMillimeterWaarden:
        """De diameter van de uitgaande as van de elektromotor."""
        return self._asdiameter.get_waarde()

    @asdiameter.setter
    def asdiameter(self, value):
        self._asdiameter.set_waarde(value, owner=self)

    @property
    def ashoogte(self) -> KwantWrdInMillimeterWaarden:
        """De afstand tussen het rustvlak van de voeten van de elektromotor en het midden van de uitgaande as."""
        return self._ashoogte.get_waarde()

    @ashoogte.setter
    def ashoogte(self, value):
        self._ashoogte.set_waarde(value, owner=self)

    @property
    def beschermingsgraad(self) -> str:
        """De beschermingsgraad geeft aan in welke mate elektrische apparatuur tegen indringing van vreemde objecten en water bestand is. Dit gebeurt met de code IP, gevolgd door twee cijfers."""
        return self._beschermingsgraad.get_waarde()

    @beschermingsgraad.setter
    def beschermingsgraad(self, value):
        self._beschermingsgraad.set_waarde(value, owner=self)

    @property
    def bouwvorm(self) -> str:
        """De bouwvorm, uitgedrukt als een IM-code, zegt iets over de wijze waarop de elektromotor gemonteerd is."""
        return self._bouwvorm.get_waarde()

    @bouwvorm.setter
    def bouwvorm(self, value):
        self._bouwvorm.set_waarde(value, owner=self)

    @property
    def gebruik(self) -> str:
        """Geeft aan hoe de elektromotor gebruikt wordt in het systeem waar hij deel van uitmaakt."""
        return self._gebruik.get_waarde()

    @gebruik.setter
    def gebruik(self, value):
        self._gebruik.set_waarde(value, owner=self)

    @property
    def heeftGeforceerdeKoeling(self) -> bool:
        """Geeft aan of de elektromotor voorzien is van geforceerde koeling."""
        return self._heeftGeforceerdeKoeling.get_waarde()

    @heeftGeforceerdeKoeling.setter
    def heeftGeforceerdeKoeling(self, value):
        self._heeftGeforceerdeKoeling.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de elektromotor."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam volgens de fabrikant van de elektromotor."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def nominaalToerental(self) -> KwantWrdInRPMWaarden:
        """Het nominale toerental van de elektromotor."""
        return self._nominaalToerental.get_waarde()

    @nominaalToerental.setter
    def nominaalToerental(self, value):
        self._nominaalToerental.set_waarde(value, owner=self)

    @property
    def nominaalVermogen(self) -> KwantWrdInKiloWattWaarden:
        """Het nominale vermogen van de elektromotor."""
        return self._nominaalVermogen.get_waarde()

    @nominaalVermogen.setter
    def nominaalVermogen(self, value):
        self._nominaalVermogen.set_waarde(value, owner=self)

    @property
    def nominaleSpanning(self) -> str:
        """De nominale spanning van de elektromotor."""
        return self._nominaleSpanning.get_waarde()

    @nominaleSpanning.setter
    def nominaleSpanning(self, value):
        self._nominaleSpanning.set_waarde(value, owner=self)

    @property
    def nominaleStroom(self) -> KwantWrdInAmpereWaarden:
        """De nominale stroom van de elektromotor."""
        return self._nominaleStroom.get_waarde()

    @nominaleStroom.setter
    def nominaleStroom(self, value):
        self._nominaleStroom.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van een elektromotor."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from abc import abstractmethod
from otlmow_model.Classes.Abstracten.Toegangselement import Toegangselement
from otlmow_model.BaseClasses.BooleanField import BooleanField
from otlmow_model.Datatypes.DtcAfmetingBxhInM import DtcAfmetingBxhInM, DtcAfmetingBxhInMWaarden
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.Datatypes.KlDeurFabrikant import KlDeurFabrikant
from otlmow_model.Datatypes.KlDeurHandgreeptype import KlDeurHandgreeptype
from otlmow_model.Datatypes.KwantWrdInMillimeter import KwantWrdInMillimeter, KwantWrdInMillimeterWaarden
from otlmow_model.Datatypes.KwantWrdInSeconde import KwantWrdInSeconde, KwantWrdInSecondeWaarden
from otlmow_model.Datatypes.KwantWrdInUur import KwantWrdInUur, KwantWrdInUurWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class Deur(Toegangselement):
    """Een beweegbaar element ter afsluiting van een ruimte. In een gebouw is een deur meestal bevestigd in een kozijn,dat weer in een muur of wand is aangebracht."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Deur'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self._afmetingDeuropening = OTLAttribuut(field=DtcAfmetingBxhInM,
                                                 naam='afmetingDeuropening',
                                                 label='afmeting deuropening',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Deur.afmetingDeuropening',
                                                 definition='Afmeting van de vrije ruimte die ontstaat wanneer de deur volledig geopend is.',
                                                 owner=self)

        self._brandweerstand = OTLAttribuut(field=KwantWrdInUur,
                                            naam='brandweerstand',
                                            label='brandweerstand',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Deur.brandweerstand',
                                            definition='Brandwerendheid is een maat voor de tijd die een constructie heeft voor dat deze bezwijkt onder invloed van een brand.',
                                            owner=self)

        self._breedte = OTLAttribuut(field=KwantWrdInMillimeter,
                                     naam='breedte',
                                     label='breedte',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Deur.breedte',
                                     definition='De afmeting van de rechtopstaande deur gemeten van de ene zijkant naar de andere.',
                                     owner=self)

        self._dikte = OTLAttribuut(field=KwantWrdInMillimeter,
                                   naam='dikte',
                                   label='dikte',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Deur.dikte',
                                   definition='De dikte van de deur gemeten van de ene buitenzijde van de deur tot de andere.',
                                   owner=self)

        self._fabrikant = OTLAttribuut(field=KlDeurFabrikant,
                                       naam='fabrikant',
                                       label='fabrikant',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Deur.fabrikant',
                                       definition='Naam van de producent van de deur.',
                                       owner=self)

        self._handgreeptype = OTLAttribuut(field=KlDeurHandgreeptype,
                                           naam='handgreeptype',
                                           label='handgreeptype',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Deur.handgreeptype',
                                           definition='Soort greep aan waarmee de deur geopend wordt.',
                                           owner=self)

        self._heeftDeurcontact = OTLAttribuut(field=BooleanField,
                                              naam='heeftDeurcontact',
                                              label='heeft deurcontact',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Deur.heeftDeurcontact',
                                              definition='Geeft aan of de deur voorzien is van een contact dat bewaakt of de deur open of dicht is.',
                                              owner=self)

        self._hoogte = OTLAttribuut(field=KwantWrdInMillimeter,
                                    naam='hoogte',
                                    label='hoogte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Deur.hoogte',
                                    definition='De afmeting van de rechtopstaande deur gemeten van de onderkant tot de bovenkant.',
                                    owner=self)

        self._isZelfsluitend = OTLAttribuut(field=BooleanField,
                                            naam='isZelfsluitend',
                                            label='is zelfsluitend',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Deur.isZelfsluitend',
                                            definition='Geeft aan of de deur voorzien is van een mechanisme dat er voor zorgt dat de deur sluit zonder tussenkomst van een gebruiker.',
                                            owner=self)

        self._ophangconstructie = OTLAttribuut(field=DtcDocument,
                                               naam='ophangconstructie',
                                               label='ophangconstructie',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Deur.ophangconstructie',
                                               definition='Documentatie met betrekking tot de manier waarop de deur met het kozijn bevestigd is aan de ruimte waartoe ze toegang biedt.',
                                               owner=self)

        self._sluitingstijd = OTLAttribuut(field=KwantWrdInSeconde,
                                           naam='sluitingstijd',
                                           label='sluitingstijd',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Deur.sluitingstijd',
                                           definition='Duurtijd voor het automatische sluiten van een zelfsluitende deur die volledig open staat.',
                                           owner=self)

    @property
    def afmetingDeuropening(self) -> DtcAfmetingBxhInMWaarden:
        """Afmeting van de vrije ruimte die ontstaat wanneer de deur volledig geopend is."""
        return self._afmetingDeuropening.get_waarde()

    @afmetingDeuropening.setter
    def afmetingDeuropening(self, value):
        self._afmetingDeuropening.set_waarde(value, owner=self)

    @property
    def brandweerstand(self) -> KwantWrdInUurWaarden:
        """Brandwerendheid is een maat voor de tijd die een constructie heeft voor dat deze bezwijkt onder invloed van een brand."""
        return self._brandweerstand.get_waarde()

    @brandweerstand.setter
    def brandweerstand(self, value):
        self._brandweerstand.set_waarde(value, owner=self)

    @property
    def breedte(self) -> KwantWrdInMillimeterWaarden:
        """De afmeting van de rechtopstaande deur gemeten van de ene zijkant naar de andere."""
        return self._breedte.get_waarde()

    @breedte.setter
    def breedte(self, value):
        self._breedte.set_waarde(value, owner=self)

    @property
    def dikte(self) -> KwantWrdInMillimeterWaarden:
        """De dikte van de deur gemeten van de ene buitenzijde van de deur tot de andere."""
        return self._dikte.get_waarde()

    @dikte.setter
    def dikte(self, value):
        self._dikte.set_waarde(value, owner=self)

    @property
    def fabrikant(self) -> str:
        """Naam van de producent van de deur."""
        return self._fabrikant.get_waarde()

    @fabrikant.setter
    def fabrikant(self, value):
        self._fabrikant.set_waarde(value, owner=self)

    @property
    def handgreeptype(self) -> str:
        """Soort greep aan waarmee de deur geopend wordt."""
        return self._handgreeptype.get_waarde()

    @handgreeptype.setter
    def handgreeptype(self, value):
        self._handgreeptype.set_waarde(value, owner=self)

    @property
    def heeftDeurcontact(self) -> bool:
        """Geeft aan of de deur voorzien is van een contact dat bewaakt of de deur open of dicht is."""
        return self._heeftDeurcontact.get_waarde()

    @heeftDeurcontact.setter
    def heeftDeurcontact(self, value):
        self._heeftDeurcontact.set_waarde(value, owner=self)

    @property
    def hoogte(self) -> KwantWrdInMillimeterWaarden:
        """De afmeting van de rechtopstaande deur gemeten van de onderkant tot de bovenkant."""
        return self._hoogte.get_waarde()

    @hoogte.setter
    def hoogte(self, value):
        self._hoogte.set_waarde(value, owner=self)

    @property
    def isZelfsluitend(self) -> bool:
        """Geeft aan of de deur voorzien is van een mechanisme dat er voor zorgt dat de deur sluit zonder tussenkomst van een gebruiker."""
        return self._isZelfsluitend.get_waarde()

    @isZelfsluitend.setter
    def isZelfsluitend(self, value):
        self._isZelfsluitend.set_waarde(value, owner=self)

    @property
    def ophangconstructie(self) -> DtcDocumentWaarden:
        """Documentatie met betrekking tot de manier waarop de deur met het kozijn bevestigd is aan de ruimte waartoe ze toegang biedt."""
        return self._ophangconstructie.get_waarde()

    @ophangconstructie.setter
    def ophangconstructie(self, value):
        self._ophangconstructie.set_waarde(value, owner=self)

    @property
    def sluitingstijd(self) -> KwantWrdInSecondeWaarden:
        """Duurtijd voor het automatische sluiten van een zelfsluitende deur die volledig open staat."""
        return self._sluitingstijd.get_waarde()

    @sluitingstijd.setter
    def sluitingstijd(self, value):
        self._sluitingstijd.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Bel(AIMNaamObject, PuntGeometrie):
    """Toestel dat door middel van een geluidssignaal de aandacht vestigt op een situatie."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMNaamObject.__init__(self)
        PuntGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElement')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Draagconstructie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Slagboomarm')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Slagboomkolom')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IOKaart')

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bel.technischeFiche',
                                             definition='De technische fiche van een bel.',
                                             owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van een bel."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlOmegaElementMateriaal(KeuzelijstField):
    """De gebruikte materialen van het omega-element."""
    naam = 'KlOmegaElementMateriaal'
    label = 'Omega element materiaal'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlOmegaElementMateriaal'
    definition = 'De gebruikte materialen van het omega-element.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlOmegaElementMateriaal'
    options = {
        'aluminium': KeuzelijstWaarde(invulwaarde='aluminium',
                                      label='aluminium',
                                      status='ingebruik',
                                      definitie='Omega-element vervaarigd uit aluminium.',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlOmegaElementMateriaal/aluminium'),
        'roestvrij-staal': KeuzelijstWaarde(invulwaarde='roestvrij-staal',
                                            label='roestvrij staal',
                                            status='ingebruik',
                                            definitie='Omega-element vervaarigd uit roestvrij staal.',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlOmegaElementMateriaal/roestvrij-staal'),
        'verzinkt-staal': KeuzelijstWaarde(invulwaarde='verzinkt-staal',
                                           label='verzinkt staal',
                                           status='ingebruik',
                                           definitie='Omega-element vervaarigd uit verzinkt staal.',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlOmegaElementMateriaal/verzinkt-staal')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlKabelmofVerbinding(KeuzelijstField):
    """Lijst van mogelijke types van verbindigen die een kabelmof kan realiseren."""
    naam = 'KlKabelmofVerbinding'
    label = 'Kabelmof verbindingtypes'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlKabelmofVerbinding'
    definition = 'Lijst van mogelijke types van verbindigen die een kabelmof kan realiseren.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlKabelmofVerbinding'
    options = {
        'doorverbinding': KeuzelijstWaarde(invulwaarde='doorverbinding',
                                           label='doorverbinding',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlKabelmofVerbinding/doorverbinding'),
        'eindmof': KeuzelijstWaarde(invulwaarde='eindmof',
                                    label='eindmof',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlKabelmofVerbinding/eindmof'),
        't-mof': KeuzelijstWaarde(invulwaarde='t-mof',
                                  label='T-mof',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlKabelmofVerbinding/t-mof'),
        'y-mof': KeuzelijstWaarde(invulwaarde='y-mof',
                                  label='Y-mof',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlKabelmofVerbinding/y-mof')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.BetonnenConstructieElement import BetonnenConstructieElement
from otlmow_model.Classes.Abstracten.ConstructieElement import ConstructieElement
from otlmow_model.Classes.Abstracten.ConstructieElementenGC import ConstructieElementenGC
from otlmow_model.Datatypes.DtcAfmetingBxlxhInCm import DtcAfmetingBxlxhInCm, DtcAfmetingBxlxhInCmWaarden
from otlmow_model.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class ConstructieSokkel(ConstructieElement, BetonnenConstructieElement, ConstructieElementenGC, VlakGeometrie):
    """Betonnen zool die het object dat erop rust verhoogt of dat dient om een structuur op een goede manier te kunnen opleggen/verbinden met de fundering."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ConstructieSokkel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        ConstructieElement.__init__(self)
        BetonnenConstructieElement.__init__(self)
        ConstructieElementenGC.__init__(self)
        VlakGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kelderlandhoofd')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kelderpijler')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Landhoofd')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pijler')

        self._afmetingen = OTLAttribuut(field=DtcAfmetingBxlxhInCm,
                                        naam='afmetingen',
                                        label='afmetingen',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ConstructieSokkel.afmetingen',
                                        definition='De afmetingen van de constructiesokkel.',
                                        owner=self)

    @property
    def afmetingen(self) -> DtcAfmetingBxlxhInCmWaarden:
        """De afmetingen van de constructiesokkel."""
        return self._afmetingen.get_waarde()

    @afmetingen.setter
    def afmetingen(self, value):
        self._afmetingen.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.BijlageVoertuigkering import BijlageVoertuigkering
from otlmow_model.Classes.Abstracten.EigenschappenVoertuigkering import EigenschappenVoertuigkering
from otlmow_model.Classes.Abstracten.Geluidsschermelement import Geluidsschermelement
from otlmow_model.Classes.Abstracten.SchokindexVoertuigkering import SchokindexVoertuigkering
from otlmow_model.Datatypes.KlLEACWerkingsbreedte import KlLEACWerkingsbreedte


# Generated with OTLClassCreator. To modify: extend, do not edit
class VoertuigkerendGeluidsschermelement(Geluidsschermelement, BijlageVoertuigkering, EigenschappenVoertuigkering, SchokindexVoertuigkering):
    """Dit zijn schermelementen met een voet in de vorm van een T. Op de voet worden deltablocs geplaatst die een stabiliserende en voertuigkerende functie hebben."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VoertuigkerendGeluidsschermelement'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        Geluidsschermelement.__init__(self)
        BijlageVoertuigkering.__init__(self)
        EigenschappenVoertuigkering.__init__(self)
        SchokindexVoertuigkering.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BevestigingGC')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElementenGC')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Fundering')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#VegetatieElement')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AfschermendeConstructie')

        self._werkingsbreedte = OTLAttribuut(field=KlLEACWerkingsbreedte,
                                             naam='werkingsbreedte',
                                             label='werkingsbreedte',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VoertuigkerendGeluidsschermelement.werkingsbreedte',
                                             definition='Dit is de afstand, op het voorvlak van een schermelement en loodrecht op de as van de weg gemeten, tussen de voorkant van het schermelement in normale positie en de plaats van het verst uitwijkend onderdeel aan de achterzijde van het schermelement bij aanrijding.',
                                             owner=self)

    @property
    def werkingsbreedte(self) -> str:
        """Dit is de afstand, op het voorvlak van een schermelement en loodrecht op de as van de weg gemeten, tussen de voorkant van het schermelement in normale positie en de plaats van het verst uitwijkend onderdeel aan de achterzijde van het schermelement bij aanrijding."""
        return self._werkingsbreedte.get_waarde()

    @werkingsbreedte.setter
    def werkingsbreedte(self, value):
        self._werkingsbreedte.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlToeslagmiddelBeton(KeuzelijstField):
    """Materiaal dat aan het beton kan worden toegevoegd."""
    naam = 'KlToeslagmiddelBeton'
    label = 'Toeslagmiddel beton'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#KlToeslagmiddelBeton'
    definition = 'Materiaal dat aan het beton kan worden toegevoegd.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlToeslagmiddelBeton'
    options = {
        'fijn-toeslagmateriaal': KeuzelijstWaarde(invulwaarde='fijn-toeslagmateriaal',
                                                  label='Fijn toeslagmateriaal',
                                                  status='ingebruik',
                                                  definitie='Een korrelgrootte van kleiner dan 4 mm, meestal bestaande uit zand.',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToeslagmiddelBeton/fijn-toeslagmateriaal'),
        'grof-toeslagmateriaal': KeuzelijstWaarde(invulwaarde='grof-toeslagmateriaal',
                                                  label='Grof toeslagmateriaal',
                                                  status='ingebruik',
                                                  definitie='Een korrelgrootte van gelijk aan of groter dan 4 mm, meestal bestaande uit grind.',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToeslagmiddelBeton/grof-toeslagmateriaal')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from typing import List
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.BaseClasses.OTLObject import OTLObject
from otlmow_model.BaseClasses.RelationInteractor import RelationInteractor
from otlmow_model.Datatypes.DtcContactinfo import DtcContactinfo, DtcContactinfoWaarden
from otlmow_model.Datatypes.DtcIdentificator import DtcIdentificator, DtcIdentificatorWaarden
from otlmow_model.BaseClasses.StringField import StringField


# Generated with OTLClassCreator. To modify: extend, do not edit
class Agent(OTLObject, RelationInteractor):
    """Iemand die of iets dat kan handelen of een effect kan teweeg brengen."""

    typeURI = 'http://purl.org/dc/terms/Agent'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        OTLObject.__init__(self)
        RelationInteractor.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HeeftBetrokkene', target='http://purl.org/dc/terms/Agent')

        self._agentId = OTLAttribuut(field=DtcIdentificator,
                                     naam='agentId',
                                     label='agent identificatie',
                                     objectUri='http://purl.org/dc/terms/Agent.agentId',
                                     definition='Identificatie van de agent volgens een bepaalde bron.',
                                     owner=self)

        self._contactinfo = OTLAttribuut(field=DtcContactinfo,
                                         naam='contactinfo',
                                         label='Contactinfo',
                                         objectUri='http://purl.org/dc/terms/Agent.contactinfo',
                                         kardinaliteit_max='*',
                                         definition='Algemene contactgegevens voor de agent.',
                                         owner=self)

        self._naam = OTLAttribuut(field=StringField,
                                  naam='naam',
                                  label='naam',
                                  objectUri='http://purl.org/dc/terms/Agent.naam',
                                  definition='De naam waarmee de agent doorgaans benoemd wordt.',
                                  owner=self)

    @property
    def agentId(self) -> DtcIdentificatorWaarden:
        """Identificatie van de agent volgens een bepaalde bron."""
        return self._agentId.get_waarde()

    @agentId.setter
    def agentId(self, value):
        self._agentId.set_waarde(value, owner=self)

    @property
    def contactinfo(self) -> List[DtcContactinfoWaarden]:
        """Algemene contactgegevens voor de agent."""
        return self._contactinfo.get_waarde()

    @contactinfo.setter
    def contactinfo(self, value):
        self._contactinfo.set_waarde(value, owner=self)

    @property
    def naam(self) -> str:
        """De naam waarmee de agent doorgaans benoemd wordt."""
        return self._naam.get_waarde()

    @naam.setter
    def naam(self, value):
        self._naam.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlWalsmethode(KeuzelijstField):
    """De manier waarop het staal is gewalst."""
    naam = 'KlWalsmethode'
    label = 'Walsmethode'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#KlWalsmethode'
    definition = 'De manier waarop het staal is gewalst.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlWalsmethode'
    options = {
        'koud': KeuzelijstWaarde(invulwaarde='koud',
                                 label='Koud',
                                 status='ingebruik',
                                 definitie='Staal die bij omgevingstemperatuur wordt gevormd (getrokken) uit warmgewalst staal.',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWalsmethode/koud'),
        'warm': KeuzelijstWaarde(invulwaarde='warm',
                                 label='Warm',
                                 status='ingebruik',
                                 definitie='Heet staal wordt vervormd onder druk van persen en walsen.',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWalsmethode/warm')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlIVRIModelRIS(KeuzelijstField):
    """De modelnaam van de RIS."""
    naam = 'KlIVRIModelRIS'
    label = 'iVRIModelRIS'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlIVRIModelRIS'
    definition = 'De modelnaam van de RIS.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlIVRIModelRIS'
    options = {
        'cloudris': KeuzelijstWaarde(invulwaarde='cloudris',
                                     label='CloudRIS',
                                     status='ingebruik',
                                     definitie='CloudRIS',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIVRIModelRIS/cloudris'),
        'virtualacu': KeuzelijstWaarde(invulwaarde='virtualacu',
                                       label='VirtualACU',
                                       status='ingebruik',
                                       definitie='VirtualACU',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIVRIModelRIS/virtualacu')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.GrazigeVegetatie import GrazigeVegetatie
from otlmow_model.Datatypes.KlNSB import KlNSB
from otlmow_model.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Ruigte(GrazigeVegetatie, VlakGeometrie):
    """Terrein of zoomvegetatie gedomineerd door ruigtekruiden of riet,die niet jaarlijks gemaaid wordt."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ruigte'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        GrazigeVegetatie.__init__(self)
        VlakGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HeeftBeheer', target='https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#BeheerGrazigeVegetatie')

        self._natuurstreefbeeld = OTLAttribuut(field=KlNSB,
                                               naam='natuurstreefbeeld',
                                               label='natuurstreefbeeld',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ruigte.natuurstreefbeeld',
                                               definition='Een natuurstreefbeeld is een nagestreefd biotoop, mozaïek van biotopen of een leefgebied van een soort dat je wil behouden of verkrijgen via een goed natuurbeheer. In het definitief plan van type twee, drie of vier wordt het ecologisch einddoel vastgesteld aan de hand van natuurstreefbeelden.',
                                               owner=self)

    @property
    def natuurstreefbeeld(self) -> str:
        """Een natuurstreefbeeld is een nagestreefd biotoop, mozaïek van biotopen of een leefgebied van een soort dat je wil behouden of verkrijgen via een goed natuurbeheer. In het definitief plan van type twee, drie of vier wordt het ecologisch einddoel vastgesteld aan de hand van natuurstreefbeelden."""
        return self._natuurstreefbeeld.get_waarde()

    @natuurstreefbeeld.setter
    def natuurstreefbeeld(self, value):
        self._natuurstreefbeeld.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from abc import abstractmethod
from otlmow_model.Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.BaseClasses.BooleanField import BooleanField
from otlmow_model.Datatypes.KlLantaarnVormgeving import KlLantaarnVormgeving
from otlmow_model.Datatypes.KlSeinlantaarnDiameter import KlSeinlantaarnDiameter
from otlmow_model.Datatypes.KlSeinlantaarnMerk import KlSeinlantaarnMerk
from otlmow_model.Datatypes.KlSeinlantaarnModelnaam import KlSeinlantaarnModelnaam
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Seinlantaarn(AIMNaamObject, PuntGeometrie):
    """Abstracte voor het geheel van één of meerdere verkeerslichten die boven elkaar worden opgesteld en worden bevestigd op een steun,teneinde de beweging van een weggebruiker die een bepaald traject volgt,te verhinderen of toe te laten."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        AIMNaamObject.__init__(self)
        PuntGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#VRIDraagconstructie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeerslicht')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestigingsbeugel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerkeerslichtGroen')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerkeerslichtOranjegeel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerkeerslichtRood')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerkeerslichtWit')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Lichtsensor')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StroomMeetmodule')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verkeersregelaar')

        self._diameter = OTLAttribuut(field=KlSeinlantaarnDiameter,
                                      naam='diameter',
                                      label='diameter',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn.diameter',
                                      definition='Diameter (in mm) van de lens van de verkeerslichten waaruit de lantaarn is samengesteld.',
                                      owner=self)

        self._heeftContrastscherm = OTLAttribuut(field=BooleanField,
                                                 naam='heeftContrastscherm',
                                                 label='heeft contrastscherm aanwezig',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn.heeftContrastscherm',
                                                 definition='Aanduiding of er een contrastscherm aanwezig is op de lantaarn.',
                                                 owner=self)

        self._merk = OTLAttribuut(field=KlSeinlantaarnMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn.merk',
                                  definition='Het merk van een de seinlantaarn.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlSeinlantaarnModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn.modelnaam',
                                       definition='De modelnaam/product range van de seinlantaarn.',
                                       owner=self)

        self._vormgeving = OTLAttribuut(field=KlLantaarnVormgeving,
                                        naam='vormgeving',
                                        label='vormgeving',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn.vormgeving',
                                        definition='Type vormgeving van de seinlantaarn.',
                                        owner=self)

    @property
    def diameter(self) -> str:
        """Diameter (in mm) van de lens van de verkeerslichten waaruit de lantaarn is samengesteld."""
        return self._diameter.get_waarde()

    @diameter.setter
    def diameter(self, value):
        self._diameter.set_waarde(value, owner=self)

    @property
    def heeftContrastscherm(self) -> bool:
        """Aanduiding of er een contrastscherm aanwezig is op de lantaarn."""
        return self._heeftContrastscherm.get_waarde()

    @heeftContrastscherm.setter
    def heeftContrastscherm(self, value):
        self._heeftContrastscherm.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Het merk van een de seinlantaarn."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam/product range van de seinlantaarn."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def vormgeving(self) -> str:
        """Type vormgeving van de seinlantaarn."""
        return self._vormgeving.get_waarde()

    @vormgeving.setter
    def vormgeving(self, value):
        self._vormgeving.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlStraatkolkType(KeuzelijstField):
    """Types van straatkolk."""
    naam = 'KlStraatkolkType'
    label = 'Straatkolk type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlStraatkolkType'
    definition = 'Types van straatkolk.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlStraatkolkType'
    options = {
        'geisoleerd': KeuzelijstWaarde(invulwaarde='geisoleerd',
                                       label='geisoleerd',
                                       status='ingebruik',
                                       definitie='Een straatkolk die niet in een rij geplaatst werd maar bijvoorbeeld ergens solitair op een plein.',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStraatkolkType/geisoleerd'),
        'horizontaal': KeuzelijstWaarde(invulwaarde='horizontaal',
                                        label='horizontaal',
                                        status='ingebruik',
                                        definitie='Een gietijzeren rooster met horizontale afvoeropening dat op regelmatige afstand geplaatst wordt langs of in een weg, fietspad of voetpad.',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStraatkolkType/horizontaal'),
        'verticaal': KeuzelijstWaarde(invulwaarde='verticaal',
                                      label='verticaal',
                                      status='ingebruik',
                                      definitie='Verticale afvoeropening die op regelmatige afstand geplaatst wordt langs of in een boordsteen van de weg, fietspad of voetpad.',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlStraatkolkType/verticaal')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlSterktereeks(KeuzelijstField):
    """De stabiliteitklasse van de buis."""
    naam = 'KlSterktereeks'
    label = 'Sterktereeks'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlSterktereeks'
    definition = 'De stabiliteitklasse van de buis.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlSterktereeks'
    options = {
        'GVP-SN10000-N-M2': KeuzelijstWaarde(invulwaarde='GVP-SN10000-N-M2',
                                             label='GVP SN10000 N/M2',
                                             status='ingebruik',
                                             definitie='GVP SN10000 N/M2',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterktereeks/GVP-SN10000-N-M2'),
        'GVP-SN2500-N-M2': KeuzelijstWaarde(invulwaarde='GVP-SN2500-N-M2',
                                            label='GVP SN2500 N/M2',
                                            status='ingebruik',
                                            definitie='GVP SN2500 N/M2',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterktereeks/GVP-SN2500-N-M2'),
        'GVP-SN5000-N-M2': KeuzelijstWaarde(invulwaarde='GVP-SN5000-N-M2',
                                            label='GVP SN5000 N/M2',
                                            status='ingebruik',
                                            definitie='GVP SN5000 N/M2',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterktereeks/GVP-SN5000-N-M2'),
        'PVC-SN16': KeuzelijstWaarde(invulwaarde='PVC-SN16',
                                     label='PVC SN16',
                                     status='ingebruik',
                                     definitie='PVC SN16',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterktereeks/PVC-SN16'),
        'PVC-SN2': KeuzelijstWaarde(invulwaarde='PVC-SN2',
                                    label='PVC SN2',
                                    status='ingebruik',
                                    definitie='PVC SN2',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterktereeks/PVC-SN2'),
        'PVC-SN4': KeuzelijstWaarde(invulwaarde='PVC-SN4',
                                    label='PVC SN4',
                                    status='ingebruik',
                                    definitie='PVC SN4',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterktereeks/PVC-SN4'),
        'PVC-SN8': KeuzelijstWaarde(invulwaarde='PVC-SN8',
                                    label='PVC SN8',
                                    status='ingebruik',
                                    definitie='PVC SN8',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterktereeks/PVC-SN8'),
        'gres-120': KeuzelijstWaarde(invulwaarde='gres-120',
                                     label='gres 120',
                                     status='ingebruik',
                                     definitie='gres 120',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterktereeks/gres-120'),
        'gres-160': KeuzelijstWaarde(invulwaarde='gres-160',
                                     label='gres 160',
                                     status='ingebruik',
                                     definitie='gres 160',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterktereeks/gres-160'),
        'gres-200': KeuzelijstWaarde(invulwaarde='gres-200',
                                     label='gres 200',
                                     status='ingebruik',
                                     definitie='gres 200',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterktereeks/gres-200'),
        'gres-240': KeuzelijstWaarde(invulwaarde='gres-240',
                                     label='gres 240',
                                     status='ingebruik',
                                     definitie='gres 240',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterktereeks/gres-240'),
        'gres-34': KeuzelijstWaarde(invulwaarde='gres-34',
                                    label='gres 34',
                                    status='ingebruik',
                                    definitie='gres 34',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterktereeks/gres-34'),
        'gres-95': KeuzelijstWaarde(invulwaarde='gres-95',
                                    label='gres 95',
                                    status='ingebruik',
                                    definitie='gres 95',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterktereeks/gres-95'),
        'gres-minimum-kruindrukwaarde-34': KeuzelijstWaarde(invulwaarde='gres-minimum-kruindrukwaarde-34',
                                                            label='gres minimum kruindrukwaarde 34',
                                                            status='ingebruik',
                                                            definitie='gres minimum kruindrukwaarde 34',
                                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterktereeks/gres-minimum-kruindrukwaarde-34'),
        'gres-minimum-kruindrukwaarde-90': KeuzelijstWaarde(invulwaarde='gres-minimum-kruindrukwaarde-90',
                                                            label='gres minimum kruindrukwaarde 90',
                                                            status='ingebruik',
                                                            definitie='gres minimum kruindrukwaarde 90',
                                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterktereeks/gres-minimum-kruindrukwaarde-90'),
        'hdpe-p-n-10': KeuzelijstWaarde(invulwaarde='hdpe-p-n-10',
                                        label='HDPE PN10',
                                        status='ingebruik',
                                        definitie='HDPE PN10',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterktereeks/hdpe-p-n-10'),
        'hdpe-p-n-16': KeuzelijstWaarde(invulwaarde='hdpe-p-n-16',
                                        label='HDPE PN16',
                                        status='ingebruik',
                                        definitie='HDPE PN16',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterktereeks/hdpe-p-n-16'),
        'pp-s-n-8': KeuzelijstWaarde(invulwaarde='pp-s-n-8',
                                     label='PP SN8',
                                     status='ingebruik',
                                     definitie='PP SN8',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterktereeks/pp-s-n-8'),
        'pvc-composiet-s-n-4': KeuzelijstWaarde(invulwaarde='pvc-composiet-s-n-4',
                                                label='PVC composiet SN4',
                                                status='ingebruik',
                                                definitie='PVC composiet SN4',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterktereeks/pvc-composiet-s-n-4'),
        'pvc-composiet-s-n-8': KeuzelijstWaarde(invulwaarde='pvc-composiet-s-n-8',
                                                label='PVC composiet SN8',
                                                status='ingebruik',
                                                definitie='PVC composiet SN8',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterktereeks/pvc-composiet-s-n-8')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.EMAfbakening import EMAfbakening
from otlmow_model.Datatypes.KlLichtzuilSoortLamp import KlLichtzuilSoortLamp
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Lichtzuil(EMAfbakening, PuntGeometrie):
    """Inwendig verlichte, geel gekleurde conische steun, inclusief het voetstuk waarop het bevestigd is, die gebruikt wordt om obstakels op de weg te signaleren voor het aankomend verkeer."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Lichtzuil'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        EMAfbakening.__init__(self)
        PuntGeometrie.__init__(self)

        self._soortLamp = OTLAttribuut(field=KlLichtzuilSoortLamp,
                                       naam='soortLamp',
                                       label='soort lamp',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Lichtzuil.soortLamp',
                                       definition='Welke soort lamp er gebruikt wordt in de lichtzuil.',
                                       owner=self)

    @property
    def soortLamp(self) -> str:
        """Welke soort lamp er gebruikt wordt in de lichtzuil."""
        return self._soortLamp.get_waarde()

    @soortLamp.setter
    def soortLamp(self, value):
        self._soortLamp.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlBGSchermelementtype(KeuzelijstField):
    """Het type bijzonder-schermelement."""
    naam = 'KlBGSchermelementtype'
    label = 'Bijzonder geluidsschermelementtype'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlBGSchermelementtype'
    definition = 'Het type bijzonder-schermelement.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlBGSchermelementtype'
    options = {
        'bloembakelement': KeuzelijstWaarde(invulwaarde='bloembakelement',
                                            label='bloembakelement',
                                            status='ingebruik',
                                            definitie='bloembakelement',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBGSchermelementtype/bloembakelement'),
        'l-element': KeuzelijstWaarde(invulwaarde='l-element',
                                      label='L-element',
                                      status='ingebruik',
                                      definitie='L-element',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBGSchermelementtype/l-element')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlGPUMerk(KeuzelijstField):
    """Het merk van de GPU."""
    naam = 'KlGPUMerk'
    label = 'GPU merk'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlGPUMerk'
    definition = 'Het merk van de GPU.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlGPUMerk'
    options = {
        'nvidia': KeuzelijstWaarde(invulwaarde='nvidia',
                                   label='Nvidia',
                                   status='ingebruik',
                                   definitie='Nvidia',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlGPUMerk/nvidia')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Datatypes.KlSchoorhoek import KlSchoorhoek
from otlmow_model.Datatypes.KwantWrdInDecimaleGraden import KwantWrdInDecimaleGraden, KwantWrdInDecimaleGradenWaarden
from otlmow_model.BaseClasses.UnionTypeField import UnionTypeField
from otlmow_model.BaseClasses.UnionWaarden import UnionWaarden


# Generated with OTLUnionDatatypeCreator. To modify: extend, do not edit
class DtuHellingsSchoorhoekWaarden(UnionWaarden):
    def __init__(self):
        UnionWaarden.__init__(self)
        self._hellingshoek = OTLAttribuut(field=KwantWrdInDecimaleGraden,
                                          naam='hellingshoek',
                                          label='hellingshoek',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtuHellingsSchoorhoek.hellingshoek',
                                          kardinaliteit_min='0',
                                          definition='Hoek die het object maakt ten opzichte van de verticale, uitgedrukt in decimale graden.',
                                          owner=self)

        self._schoorhoek = OTLAttribuut(field=KlSchoorhoek,
                                        naam='schoorhoek',
                                        label='schoorhoek',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtuHellingsSchoorhoek.schoorhoek',
                                        kardinaliteit_min='0',
                                        definition='Hoek die het object maakt ten opzichte van de verticale, uitgedrukt in 1 op x (vb.: 1/4).',
                                        owner=self)

    @property
    def hellingshoek(self) -> KwantWrdInDecimaleGradenWaarden:
        """Hoek die het object maakt ten opzichte van de verticale, uitgedrukt in decimale graden."""
        return self._hellingshoek.get_waarde()

    @hellingshoek.setter
    def hellingshoek(self, value):
        self._hellingshoek.set_waarde(value, owner=self._parent)
        if value is not None:
            self.clear_other_props('_hellingshoek')

    @property
    def schoorhoek(self) -> str:
        """Hoek die het object maakt ten opzichte van de verticale, uitgedrukt in 1 op x (vb.: 1/4)."""
        return self._schoorhoek.get_waarde()

    @schoorhoek.setter
    def schoorhoek(self, value):
        self._schoorhoek.set_waarde(value, owner=self._parent)
        if value is not None:
            self.clear_other_props('_schoorhoek')


# Generated with OTLUnionDatatypeCreator. To modify: extend, do not edit
class DtuHellingsSchoorhoek(UnionTypeField):
    """Union datatype voor de hellings- of de schoorhoek."""
    naam = 'DtuHellingsSchoorhoek'
    label = 'Hellings- of schoorhoek'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtuHellingsSchoorhoek'
    definition = 'Union datatype voor de hellings- of de schoorhoek.'
    waardeObject = DtuHellingsSchoorhoekWaarden

    def __str__(self):
        return UnionTypeField.__str__(self)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlGebruiksdomein(KeuzelijstField):
    """De omstandigheden waarin het beton gebruikt zal worden."""
    naam = 'KlGebruiksdomein'
    label = 'Gebruiksdomein'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#KlGebruiksdomein'
    definition = 'De omstandigheden waarin het beton gebruikt zal worden.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlGebruiksdomein'
    options = {
        'gb-gewapend': KeuzelijstWaarde(invulwaarde='gb-gewapend',
                                        label='GB (gewapend)',
                                        status='ingebruik',
                                        definitie='Gewapend beton.',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlGebruiksdomein/gb-gewapend'),
        'gzb-gewapend-zichtbeton': KeuzelijstWaarde(invulwaarde='gzb-gewapend-zichtbeton',
                                                    label='GZB (gewapend zichtbeton) ',
                                                    status='ingebruik',
                                                    definitie='Gewapend zichtbeton.',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlGebruiksdomein/gzb-gewapend-zichtbeton'),
        'ob-ongewapend': KeuzelijstWaarde(invulwaarde='ob-ongewapend',
                                          label='OB (ongewapend)',
                                          status='ingebruik',
                                          definitie='Ongewapend beton.',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlGebruiksdomein/ob-ongewapend'),
        'vb-voorgespannen': KeuzelijstWaarde(invulwaarde='vb-voorgespannen',
                                             label='VB (voorgespannen)',
                                             status='ingebruik',
                                             definitie='Voorgespannen beton.',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlGebruiksdomein/vb-voorgespannen')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

